@@ -43,6 +43,39 @@ class OrderManagerAsync(AsyncClient):
             return {}, False
         return data, True
 
+    async def create_order_v2(
+        self,
+        product_id: str,
+        body: str = None,
+        remark: str = None,
+        payment_channel: str = "WECHAT",
+    ):
+        """
+        description:
+            创建订单并直接返回支付二维码（V2，推荐）。
+            相比旧流程（create_order + generate_qr_code），该接口一次请求完成下单和二维码链接生成。
+        parameters:
+            product_id(str): 产品ID
+            body(str): 商品描述
+            remark(str): 订单备注
+            payment_channel(str): 支付渠道，可选值："WECHAT"、"ALIPAY"、"PAYPAL"
+        return:
+            data(dict): 返回数据
+                - order(dict): 订单信息（字段同 create_order 返回）
+                - qr_code_url(str): 支付二维码图片URL
+            success(bool): 操作是否成功
+        """
+        data = {
+            "product_id": product_id,
+            "body": body,
+            "remark": remark,
+            "payment_channel": payment_channel,
+        }
+        data, success = await self._request("POST", "/api/orders/create_v2", json=data)
+        if not success:
+            return {}, False
+        return data, True
+
     async def list_order(
         self,
         page: int = 1,
@@ -259,3 +292,76 @@ class OrderManagerAsync(AsyncClient):
         if not success:
             return {}, False
         return data, True
+
+    async def get_revenue_trend(
+        self,
+        start_date: str = None,
+        end_date: str = None,
+        dimension: str = "day",
+    ):
+        """
+        description:
+            获取收入趋势统计，只统计已支付(PAID)的订单。支持按日、按周、按月三种维度统计。
+        parameters:
+            start_date(str): 开始日期，格式：YYYY-MM-DD，可选
+            end_date(str): 结束日期，格式：YYYY-MM-DD，可选
+            dimension(str): 统计维度，可选值："day"（按日）、"week"（按周）、"month"（按月），默认为"day"
+        return:
+            data(dict): 收入趋势统计信息
+                - trend(list): 趋势数据列表
+                    - date(str): 日期或时间段
+                    - revenue(float): 收入金额（元）
+                    - order_count(int): 订单数量
+                - dimension(str): 统计维度
+                - start_date(str): 开始日期
+                - end_date(str): 结束日期
+            success(bool): 操作是否成功
+        """
+        params = {
+            "dimension": dimension,
+        }
+        if start_date is not None:
+            params["start_date"] = start_date
+        if end_date is not None:
+            params["end_date"] = end_date
+        data, success = await self._request("GET", "/api/orders/stats/revenue-trend", params=params)
+        if not success:
+            return {}, False
+        return data, True
+
+    async def get_product_revenue_ranking(
+        self,
+        start_date: str = None,
+        end_date: str = None,
+        limit: int = 10,
+    ):
+        """
+        description:
+            获取产品收入排名，只统计已支付(PAID)的订单。按收入金额降序排列。
+        parameters:
+            start_date(str): 开始日期，格式：YYYY-MM-DD，可选
+            end_date(str): 结束日期，格式：YYYY-MM-DD，可选
+            limit(int): 返回排名数量，默认为10，最大100
+        return:
+            data(dict): 产品收入排名信息
+                - ranking(list): 排名列表
+                    - product_id(int): 产品ID
+                    - product_name(str): 产品名称
+                    - product_category(str): 产品分类
+                    - revenue(float): 收入金额（元）
+                    - order_count(int): 订单数量
+                - start_date(str): 开始日期
+                - end_date(str): 结束日期
+            success(bool): 操作是否成功
+        """
+        params = {
+            "limit": limit,
+        }
+        if start_date is not None:
+            params["start_date"] = start_date
+        if end_date is not None:
+            params["end_date"] = end_date
+        data, success = await self._request("GET", "/api/orders/stats/product-ranking", params=params)
+        if not success:
+            return {}, False
+        return data, True
